@@ -1,8 +1,9 @@
-from threading import Thread
+
 import time
 
 from .settings import SettingsBase
-from .threads import AutomagicManager
+from .threading import Manager
+from .util import convert_position, chain
 
 __all__ = [
     "Module", "AsyncModule", "IntervalModule",
@@ -10,6 +11,7 @@ __all__ = [
 
 class Module(SettingsBase):
     output = None
+    position = 0
 
     def registered(self, status_handler):
         """Called when this module is registered with a status handler"""
@@ -19,7 +21,14 @@ class Module(SettingsBase):
             if "name" not in self.output:
                 self.output["name"] = self.__name__
             self.output["instance"] = str(id(self))
-            json.insert(0, self.output)
+            json.insert(convert_position(self.position, json), self.output)
+
+    def test(self):
+        """
+        Return True if settings seem ok (i.e. login credentials and such are valid)
+        or a string describing the problem
+        """
+        return True
 
     def on_click(self, button):
         if button == 1: # Left mouse button
@@ -27,6 +36,10 @@ class Module(SettingsBase):
         elif button == 3: # Right mouse button
             self.on_rightclick()
 
+    @chain
+    def move(self, position):
+        self.position = position
+
     def on_leftclick(self):
         pass
 
@@ -36,15 +49,6 @@ class Module(SettingsBase):
     def __repr__(self):
         return self.__class__.__name__
 
-class AsyncModule(Module):
-    def registered(self, status_handler):
-        self.thread = Thread(target=self.mainloop)
-        self.thread.daemon = True
-        self.thread.start()
-
-    def mainloop(self):
-        """This is run in a separate daemon-thread"""
-
 class IntervalModule(Module):
     interval = 5 # seconds
     managers = {}
@@ -53,7 +57,7 @@ class IntervalModule(Module):
         if self.interval in IntervalModule.managers:
             IntervalModule.managers[self.interval].append(self)
         else:
-            am = AutomagicManager(self.interval)
+            am = Manager(self.interval)
             am.append(self)
             IntervalModule.managers[self.interval] = am
 
